@@ -392,14 +392,18 @@ class OOSheet(OODoc):
 
     def flatten(self):
         """Keeps the value and string of cells in selection, but make them independent of a formula."""
-        for cell in self.cells:
-            if cell.getValue():
-                cell.setValue(cell.getValue())
-            elif cell.getString():
-                cell.setString(cell.getString())
-            
+        self.copy()
+        self.focus()
+        self.dispatch('.uno:InsertContents',
+                      ('Flags', 'SVDNT'),
+                      ('FormulaCommand', 0),
+                      ('SkipEmptyCells', False),
+                      ('Transpose', False),
+                      ('AsLink', False),
+                      ('MoveMode', 4),
+                      )
         return self
-
+        
     @property
     def first_row(self):
         return self.clone().shrink_down(self.height - 1)
@@ -441,7 +445,10 @@ class OOSheet(OODoc):
         Internally, copies the other selector and does a "paste special" in the current cells,
         pasting everything but data. No success has been achieved while trying to use the "brush" tool.
         """
-        
+
+        if type(selector) is type(self):
+            selector = selector.selector
+            
         OOSheet(selector).copy()
         self.focus()
         self.dispatch('.uno:InsertContents',
